==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/HttpRouteMatchRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a rule for http route matching.
 * @property headers headers and their values to match in request.
 * @property path Path to match for routing.
 */
public data class HttpRouteMatchRuleArgs(
    public val headers: Output<List<HttpRouteMatchHeaderArgs>>? = null,
    public val path: Output<HttpRouteMatchPathArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchRuleArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchRuleArgs.builder()
            .headers(
                headers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .path(path.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [HttpRouteMatchRuleArgs].
 */
@PulumiTagMarker
public class HttpRouteMatchRuleArgsBuilder internal constructor() {
    private var headers: Output<List<HttpRouteMatchHeaderArgs>>? = null

    private var path: Output<HttpRouteMatchPathArgs>? = null

    /**
     * @param value headers and their values to match in request.
     */
    @JvmName("siicsiimwdwrytwb")
    public suspend fun headers(`value`: Output<List<HttpRouteMatchHeaderArgs>>) {
        this.headers = value
    }

    @JvmName("fponjsbefthuqrbb")
    public suspend fun headers(vararg values: Output<HttpRouteMatchHeaderArgs>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values headers and their values to match in request.
     */
    @JvmName("kagjhrgjhwgoqsef")
    public suspend fun headers(values: List<Output<HttpRouteMatchHeaderArgs>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value Path to match for routing.
     */
    @JvmName("cemkwmiowsaajusl")
    public suspend fun path(`value`: Output<HttpRouteMatchPathArgs>) {
        this.path = value
    }

    /**
     * @param value headers and their values to match in request.
     */
    @JvmName("eljdredrcpuulfym")
    public suspend fun headers(`value`: List<HttpRouteMatchHeaderArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param argument headers and their values to match in request.
     */
    @JvmName("uebjktbuuoroypdt")
    public suspend fun headers(argument: List<suspend HttpRouteMatchHeaderArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            HttpRouteMatchHeaderArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument headers and their values to match in request.
     */
    @JvmName("hoavwkhghuvwkirr")
    public suspend fun headers(vararg argument: suspend HttpRouteMatchHeaderArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            HttpRouteMatchHeaderArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument headers and their values to match in request.
     */
    @JvmName("chtfbikqahxdbnoi")
    public suspend fun headers(argument: suspend HttpRouteMatchHeaderArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(HttpRouteMatchHeaderArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param values headers and their values to match in request.
     */
    @JvmName("sxcryoidglinrwaw")
    public suspend fun headers(vararg values: HttpRouteMatchHeaderArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value Path to match for routing.
     */
    @JvmName("kndekvdjcbrbhffk")
    public suspend fun path(`value`: HttpRouteMatchPathArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param argument Path to match for routing.
     */
    @JvmName("empgewhtmxdqbbba")
    public suspend fun path(argument: suspend HttpRouteMatchPathArgsBuilder.() -> Unit) {
        val toBeMapped = HttpRouteMatchPathArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.path = mapped
    }

    internal fun build(): HttpRouteMatchRuleArgs = HttpRouteMatchRuleArgs(
        headers = headers,
        path = path ?: throw PulumiNullFieldException("path"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/HttpRouteMatchRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a rule for http route matching.
 * @property headers headers and their values to match in request.
 * @property path Path to match for routing.
 */
public data class HttpRouteMatchRuleArgs(
    public val headers: Output<List<HttpRouteMatchHeaderArgs>>? = null,
    public val path: Output<HttpRouteMatchPathArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchRuleArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchRuleArgs.builder()
            .headers(
                headers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .path(path.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [HttpRouteMatchRuleArgs].
 */
@PulumiTagMarker
public class HttpRouteMatchRuleArgsBuilder internal constructor() {
    private var headers: Output<List<HttpRouteMatchHeaderArgs>>? = null

    private var path: Output<HttpRouteMatchPathArgs>? = null

    /**
     * @param value headers and their values to match in request.
     */
    @JvmName("leeswrupmusadwtm")
    public suspend fun headers(`value`: Output<List<HttpRouteMatchHeaderArgs>>) {
        this.headers = value
    }

    @JvmName("eauqgfwbucvyatvv")
    public suspend fun headers(vararg values: Output<HttpRouteMatchHeaderArgs>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values headers and their values to match in request.
     */
    @JvmName("jcjfwdihdyrphcab")
    public suspend fun headers(values: List<Output<HttpRouteMatchHeaderArgs>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value Path to match for routing.
     */
    @JvmName("mmaehguiuwyclqck")
    public suspend fun path(`value`: Output<HttpRouteMatchPathArgs>) {
        this.path = value
    }

    /**
     * @param value headers and their values to match in request.
     */
    @JvmName("bbuxdhtbtohymhoq")
    public suspend fun headers(`value`: List<HttpRouteMatchHeaderArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param argument headers and their values to match in request.
     */
    @JvmName("ltlkvquhejavvfqt")
    public suspend fun headers(argument: List<suspend HttpRouteMatchHeaderArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            HttpRouteMatchHeaderArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument headers and their values to match in request.
     */
    @JvmName("ouupjakapwhfrytu")
    public suspend fun headers(vararg argument: suspend HttpRouteMatchHeaderArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            HttpRouteMatchHeaderArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param argument headers and their values to match in request.
     */
    @JvmName("hbyrwotkuupnbigm")
    public suspend fun headers(argument: suspend HttpRouteMatchHeaderArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(HttpRouteMatchHeaderArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.headers = mapped
    }

    /**
     * @param values headers and their values to match in request.
     */
    @JvmName("bedvmwldjtebxpcw")
    public suspend fun headers(vararg values: HttpRouteMatchHeaderArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value Path to match for routing.
     */
    @JvmName("mthxbcmqtxdfricf")
    public suspend fun path(`value`: HttpRouteMatchPathArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param argument Path to match for routing.
     */
    @JvmName("esbrhclhgmbfcncq")
    public suspend fun path(argument: suspend HttpRouteMatchPathArgsBuilder.() -> Unit) {
        val toBeMapped = HttpRouteMatchPathArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.path = mapped
    }

    internal fun build(): HttpRouteMatchRuleArgs = HttpRouteMatchRuleArgs(
        headers = headers,
        path = path ?: throw PulumiNullFieldException("path"),
    )
}
